# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1UsageDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billed_bytes': 'str',
        'billed_time_seconds': 'str',
        'cost': 'float',
        'ended_at': 'datetime',
        'free': 'bool',
        'hourly_price': 'float',
        'instance_count': 'str',
        'instance_type': 'str',
        'saved_cost': 'float',
        'spot': 'bool',
        'started_at': 'datetime'
    }

    attribute_map = {
        'billed_bytes': 'billedBytes',
        'billed_time_seconds': 'billedTimeSeconds',
        'cost': 'cost',
        'ended_at': 'endedAt',
        'free': 'free',
        'hourly_price': 'hourlyPrice',
        'instance_count': 'instanceCount',
        'instance_type': 'instanceType',
        'saved_cost': 'savedCost',
        'spot': 'spot',
        'started_at': 'startedAt'
    }

    def __init__(self, billed_bytes: 'str' =None, billed_time_seconds: 'str' =None, cost: 'float' =None, ended_at: 'datetime' =None, free: 'bool' =None, hourly_price: 'float' =None, instance_count: 'str' =None, instance_type: 'str' =None, saved_cost: 'float' =None, spot: 'bool' =None, started_at: 'datetime' =None):  # noqa: E501
        """V1UsageDetails - a model defined in Swagger"""  # noqa: E501
        self._billed_bytes = None
        self._billed_time_seconds = None
        self._cost = None
        self._ended_at = None
        self._free = None
        self._hourly_price = None
        self._instance_count = None
        self._instance_type = None
        self._saved_cost = None
        self._spot = None
        self._started_at = None
        self.discriminator = None
        if billed_bytes is not None:
            self.billed_bytes = billed_bytes
        if billed_time_seconds is not None:
            self.billed_time_seconds = billed_time_seconds
        if cost is not None:
            self.cost = cost
        if ended_at is not None:
            self.ended_at = ended_at
        if free is not None:
            self.free = free
        if hourly_price is not None:
            self.hourly_price = hourly_price
        if instance_count is not None:
            self.instance_count = instance_count
        if instance_type is not None:
            self.instance_type = instance_type
        if saved_cost is not None:
            self.saved_cost = saved_cost
        if spot is not None:
            self.spot = spot
        if started_at is not None:
            self.started_at = started_at

    @property
    def billed_bytes(self) -> 'str':
        """Gets the billed_bytes of this V1UsageDetails.  # noqa: E501


        :return: The billed_bytes of this V1UsageDetails.  # noqa: E501
        :rtype: str
        """
        return self._billed_bytes

    @billed_bytes.setter
    def billed_bytes(self, billed_bytes: 'str'):
        """Sets the billed_bytes of this V1UsageDetails.


        :param billed_bytes: The billed_bytes of this V1UsageDetails.  # noqa: E501
        :type: str
        """

        self._billed_bytes = billed_bytes

    @property
    def billed_time_seconds(self) -> 'str':
        """Gets the billed_time_seconds of this V1UsageDetails.  # noqa: E501


        :return: The billed_time_seconds of this V1UsageDetails.  # noqa: E501
        :rtype: str
        """
        return self._billed_time_seconds

    @billed_time_seconds.setter
    def billed_time_seconds(self, billed_time_seconds: 'str'):
        """Sets the billed_time_seconds of this V1UsageDetails.


        :param billed_time_seconds: The billed_time_seconds of this V1UsageDetails.  # noqa: E501
        :type: str
        """

        self._billed_time_seconds = billed_time_seconds

    @property
    def cost(self) -> 'float':
        """Gets the cost of this V1UsageDetails.  # noqa: E501


        :return: The cost of this V1UsageDetails.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost: 'float'):
        """Sets the cost of this V1UsageDetails.


        :param cost: The cost of this V1UsageDetails.  # noqa: E501
        :type: float
        """

        self._cost = cost

    @property
    def ended_at(self) -> 'datetime':
        """Gets the ended_at of this V1UsageDetails.  # noqa: E501


        :return: The ended_at of this V1UsageDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at: 'datetime'):
        """Sets the ended_at of this V1UsageDetails.


        :param ended_at: The ended_at of this V1UsageDetails.  # noqa: E501
        :type: datetime
        """

        self._ended_at = ended_at

    @property
    def free(self) -> 'bool':
        """Gets the free of this V1UsageDetails.  # noqa: E501


        :return: The free of this V1UsageDetails.  # noqa: E501
        :rtype: bool
        """
        return self._free

    @free.setter
    def free(self, free: 'bool'):
        """Sets the free of this V1UsageDetails.


        :param free: The free of this V1UsageDetails.  # noqa: E501
        :type: bool
        """

        self._free = free

    @property
    def hourly_price(self) -> 'float':
        """Gets the hourly_price of this V1UsageDetails.  # noqa: E501


        :return: The hourly_price of this V1UsageDetails.  # noqa: E501
        :rtype: float
        """
        return self._hourly_price

    @hourly_price.setter
    def hourly_price(self, hourly_price: 'float'):
        """Sets the hourly_price of this V1UsageDetails.


        :param hourly_price: The hourly_price of this V1UsageDetails.  # noqa: E501
        :type: float
        """

        self._hourly_price = hourly_price

    @property
    def instance_count(self) -> 'str':
        """Gets the instance_count of this V1UsageDetails.  # noqa: E501


        :return: The instance_count of this V1UsageDetails.  # noqa: E501
        :rtype: str
        """
        return self._instance_count

    @instance_count.setter
    def instance_count(self, instance_count: 'str'):
        """Sets the instance_count of this V1UsageDetails.


        :param instance_count: The instance_count of this V1UsageDetails.  # noqa: E501
        :type: str
        """

        self._instance_count = instance_count

    @property
    def instance_type(self) -> 'str':
        """Gets the instance_type of this V1UsageDetails.  # noqa: E501


        :return: The instance_type of this V1UsageDetails.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type: 'str'):
        """Sets the instance_type of this V1UsageDetails.


        :param instance_type: The instance_type of this V1UsageDetails.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def saved_cost(self) -> 'float':
        """Gets the saved_cost of this V1UsageDetails.  # noqa: E501


        :return: The saved_cost of this V1UsageDetails.  # noqa: E501
        :rtype: float
        """
        return self._saved_cost

    @saved_cost.setter
    def saved_cost(self, saved_cost: 'float'):
        """Sets the saved_cost of this V1UsageDetails.


        :param saved_cost: The saved_cost of this V1UsageDetails.  # noqa: E501
        :type: float
        """

        self._saved_cost = saved_cost

    @property
    def spot(self) -> 'bool':
        """Gets the spot of this V1UsageDetails.  # noqa: E501


        :return: The spot of this V1UsageDetails.  # noqa: E501
        :rtype: bool
        """
        return self._spot

    @spot.setter
    def spot(self, spot: 'bool'):
        """Sets the spot of this V1UsageDetails.


        :param spot: The spot of this V1UsageDetails.  # noqa: E501
        :type: bool
        """

        self._spot = spot

    @property
    def started_at(self) -> 'datetime':
        """Gets the started_at of this V1UsageDetails.  # noqa: E501


        :return: The started_at of this V1UsageDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at: 'datetime'):
        """Sets the started_at of this V1UsageDetails.


        :param started_at: The started_at of this V1UsageDetails.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1UsageDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1UsageDetails') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1UsageDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1UsageDetails') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1Project(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'abac_enabled': 'bool',
        'created_at': 'datetime',
        'description': 'str',
        'display_name': 'str',
        'id': 'str',
        'name': 'str',
        'owner_id': 'str',
        'owner_type': 'V1OwnerType',
        'private': 'bool',
        'project_settings': 'V1ProjectSettings',
        'quotas': 'V1Quotas',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'abac_enabled': 'abacEnabled',
        'created_at': 'createdAt',
        'description': 'description',
        'display_name': 'displayName',
        'id': 'id',
        'name': 'name',
        'owner_id': 'ownerId',
        'owner_type': 'ownerType',
        'private': 'private',
        'project_settings': 'projectSettings',
        'quotas': 'quotas',
        'updated_at': 'updatedAt'
    }

    def __init__(self, abac_enabled: 'bool' =None, created_at: 'datetime' =None, description: 'str' =None, display_name: 'str' =None, id: 'str' =None, name: 'str' =None, owner_id: 'str' =None, owner_type: 'V1OwnerType' =None, private: 'bool' =None, project_settings: 'V1ProjectSettings' =None, quotas: 'V1Quotas' =None, updated_at: 'datetime' =None):  # noqa: E501
        """V1Project - a model defined in Swagger"""  # noqa: E501
        self._abac_enabled = None
        self._created_at = None
        self._description = None
        self._display_name = None
        self._id = None
        self._name = None
        self._owner_id = None
        self._owner_type = None
        self._private = None
        self._project_settings = None
        self._quotas = None
        self._updated_at = None
        self.discriminator = None
        if abac_enabled is not None:
            self.abac_enabled = abac_enabled
        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if owner_id is not None:
            self.owner_id = owner_id
        if owner_type is not None:
            self.owner_type = owner_type
        if private is not None:
            self.private = private
        if project_settings is not None:
            self.project_settings = project_settings
        if quotas is not None:
            self.quotas = quotas
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def abac_enabled(self) -> 'bool':
        """Gets the abac_enabled of this V1Project.  # noqa: E501


        :return: The abac_enabled of this V1Project.  # noqa: E501
        :rtype: bool
        """
        return self._abac_enabled

    @abac_enabled.setter
    def abac_enabled(self, abac_enabled: 'bool'):
        """Sets the abac_enabled of this V1Project.


        :param abac_enabled: The abac_enabled of this V1Project.  # noqa: E501
        :type: bool
        """

        self._abac_enabled = abac_enabled

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1Project.  # noqa: E501


        :return: The created_at of this V1Project.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1Project.


        :param created_at: The created_at of this V1Project.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self) -> 'str':
        """Gets the description of this V1Project.  # noqa: E501


        :return: The description of this V1Project.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1Project.


        :param description: The description of this V1Project.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1Project.  # noqa: E501


        :return: The display_name of this V1Project.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1Project.


        :param display_name: The display_name of this V1Project.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def id(self) -> 'str':
        """Gets the id of this V1Project.  # noqa: E501


        :return: The id of this V1Project.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1Project.


        :param id: The id of this V1Project.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self) -> 'str':
        """Gets the name of this V1Project.  # noqa: E501


        :return: The name of this V1Project.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1Project.


        :param name: The name of this V1Project.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def owner_id(self) -> 'str':
        """Gets the owner_id of this V1Project.  # noqa: E501


        :return: The owner_id of this V1Project.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id: 'str'):
        """Sets the owner_id of this V1Project.


        :param owner_id: The owner_id of this V1Project.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def owner_type(self) -> 'V1OwnerType':
        """Gets the owner_type of this V1Project.  # noqa: E501


        :return: The owner_type of this V1Project.  # noqa: E501
        :rtype: V1OwnerType
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type: 'V1OwnerType'):
        """Sets the owner_type of this V1Project.


        :param owner_type: The owner_type of this V1Project.  # noqa: E501
        :type: V1OwnerType
        """

        self._owner_type = owner_type

    @property
    def private(self) -> 'bool':
        """Gets the private of this V1Project.  # noqa: E501


        :return: The private of this V1Project.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private: 'bool'):
        """Sets the private of this V1Project.


        :param private: The private of this V1Project.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def project_settings(self) -> 'V1ProjectSettings':
        """Gets the project_settings of this V1Project.  # noqa: E501


        :return: The project_settings of this V1Project.  # noqa: E501
        :rtype: V1ProjectSettings
        """
        return self._project_settings

    @project_settings.setter
    def project_settings(self, project_settings: 'V1ProjectSettings'):
        """Sets the project_settings of this V1Project.


        :param project_settings: The project_settings of this V1Project.  # noqa: E501
        :type: V1ProjectSettings
        """

        self._project_settings = project_settings

    @property
    def quotas(self) -> 'V1Quotas':
        """Gets the quotas of this V1Project.  # noqa: E501


        :return: The quotas of this V1Project.  # noqa: E501
        :rtype: V1Quotas
        """
        return self._quotas

    @quotas.setter
    def quotas(self, quotas: 'V1Quotas'):
        """Sets the quotas of this V1Project.


        :param quotas: The quotas of this V1Project.  # noqa: E501
        :type: V1Quotas
        """

        self._quotas = quotas

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1Project.  # noqa: E501


        :return: The updated_at of this V1Project.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1Project.


        :param updated_at: The updated_at of this V1Project.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Project, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Project') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Project):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1Project') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class SlurmJobsBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloudspace_id': 'str',
        'cluster_id': 'str',
        'command': 'str',
        'name': 'str',
        'sync_env': 'bool',
        'work_dir': 'str'
    }

    attribute_map = {
        'cloudspace_id': 'cloudspaceId',
        'cluster_id': 'clusterId',
        'command': 'command',
        'name': 'name',
        'sync_env': 'syncEnv',
        'work_dir': 'workDir'
    }

    def __init__(self, cloudspace_id: 'str' =None, cluster_id: 'str' =None, command: 'str' =None, name: 'str' =None, sync_env: 'bool' =None, work_dir: 'str' =None):  # noqa: E501
        """SlurmJobsBody - a model defined in Swagger"""  # noqa: E501
        self._cloudspace_id = None
        self._cluster_id = None
        self._command = None
        self._name = None
        self._sync_env = None
        self._work_dir = None
        self.discriminator = None
        if cloudspace_id is not None:
            self.cloudspace_id = cloudspace_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if command is not None:
            self.command = command
        if name is not None:
            self.name = name
        if sync_env is not None:
            self.sync_env = sync_env
        if work_dir is not None:
            self.work_dir = work_dir

    @property
    def cloudspace_id(self) -> 'str':
        """Gets the cloudspace_id of this SlurmJobsBody.  # noqa: E501


        :return: The cloudspace_id of this SlurmJobsBody.  # noqa: E501
        :rtype: str
        """
        return self._cloudspace_id

    @cloudspace_id.setter
    def cloudspace_id(self, cloudspace_id: 'str'):
        """Sets the cloudspace_id of this SlurmJobsBody.


        :param cloudspace_id: The cloudspace_id of this SlurmJobsBody.  # noqa: E501
        :type: str
        """

        self._cloudspace_id = cloudspace_id

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this SlurmJobsBody.  # noqa: E501


        :return: The cluster_id of this SlurmJobsBody.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this SlurmJobsBody.


        :param cluster_id: The cluster_id of this SlurmJobsBody.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def command(self) -> 'str':
        """Gets the command of this SlurmJobsBody.  # noqa: E501


        :return: The command of this SlurmJobsBody.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command: 'str'):
        """Sets the command of this SlurmJobsBody.


        :param command: The command of this SlurmJobsBody.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def name(self) -> 'str':
        """Gets the name of this SlurmJobsBody.  # noqa: E501

        required parameter when creating a job.  # noqa: E501

        :return: The name of this SlurmJobsBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this SlurmJobsBody.

        required parameter when creating a job.  # noqa: E501

        :param name: The name of this SlurmJobsBody.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sync_env(self) -> 'bool':
        """Gets the sync_env of this SlurmJobsBody.  # noqa: E501


        :return: The sync_env of this SlurmJobsBody.  # noqa: E501
        :rtype: bool
        """
        return self._sync_env

    @sync_env.setter
    def sync_env(self, sync_env: 'bool'):
        """Sets the sync_env of this SlurmJobsBody.


        :param sync_env: The sync_env of this SlurmJobsBody.  # noqa: E501
        :type: bool
        """

        self._sync_env = sync_env

    @property
    def work_dir(self) -> 'str':
        """Gets the work_dir of this SlurmJobsBody.  # noqa: E501


        :return: The work_dir of this SlurmJobsBody.  # noqa: E501
        :rtype: str
        """
        return self._work_dir

    @work_dir.setter
    def work_dir(self, work_dir: 'str'):
        """Sets the work_dir of this SlurmJobsBody.


        :param work_dir: The work_dir of this SlurmJobsBody.  # noqa: E501
        :type: str
        """

        self._work_dir = work_dir

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SlurmJobsBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'SlurmJobsBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, SlurmJobsBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'SlurmJobsBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1LightningworkSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'build_spec': 'V1BuildSpec',
        'cloud_space_id': 'str',
        'cluster_driver': 'V1LightningworkClusterDriver',
        'cluster_id': 'str',
        'compute_config': 'V1ComputeConfig',
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'data_connections': 'list[V1DataConnection]',
        'desired_state': 'V1LightningworkState',
        'drives': 'list[V1LightningworkDrives]',
        'env': 'list[V1EnvVar]',
        'lightningapp_instance_id': 'str',
        'network_config': 'list[V1NetworkConfig]',
        'pause_automation': 'bool',
        'restart_policy': 'V1LightningappRestartPolicy',
        'user_id': 'str',
        'user_requested_compute_config': 'V1UserRequestedComputeConfig'
    }

    attribute_map = {
        'build_spec': 'buildSpec',
        'cloud_space_id': 'cloudSpaceId',
        'cluster_driver': 'clusterDriver',
        'cluster_id': 'clusterId',
        'compute_config': 'computeConfig',
        'data_connection_mounts': 'dataConnectionMounts',
        'data_connections': 'dataConnections',
        'desired_state': 'desiredState',
        'drives': 'drives',
        'env': 'env',
        'lightningapp_instance_id': 'lightningappInstanceId',
        'network_config': 'networkConfig',
        'pause_automation': 'pauseAutomation',
        'restart_policy': 'restartPolicy',
        'user_id': 'userId',
        'user_requested_compute_config': 'userRequestedComputeConfig'
    }

    def __init__(self, build_spec: 'V1BuildSpec' =None, cloud_space_id: 'str' =None, cluster_driver: 'V1LightningworkClusterDriver' =None, cluster_id: 'str' =None, compute_config: 'V1ComputeConfig' =None, data_connection_mounts: 'list[V1DataConnectionMount]' =None, data_connections: 'list[V1DataConnection]' =None, desired_state: 'V1LightningworkState' =None, drives: 'list[V1LightningworkDrives]' =None, env: 'list[V1EnvVar]' =None, lightningapp_instance_id: 'str' =None, network_config: 'list[V1NetworkConfig]' =None, pause_automation: 'bool' =None, restart_policy: 'V1LightningappRestartPolicy' =None, user_id: 'str' =None, user_requested_compute_config: 'V1UserRequestedComputeConfig' =None):  # noqa: E501
        """V1LightningworkSpec - a model defined in Swagger"""  # noqa: E501
        self._build_spec = None
        self._cloud_space_id = None
        self._cluster_driver = None
        self._cluster_id = None
        self._compute_config = None
        self._data_connection_mounts = None
        self._data_connections = None
        self._desired_state = None
        self._drives = None
        self._env = None
        self._lightningapp_instance_id = None
        self._network_config = None
        self._pause_automation = None
        self._restart_policy = None
        self._user_id = None
        self._user_requested_compute_config = None
        self.discriminator = None
        if build_spec is not None:
            self.build_spec = build_spec
        if cloud_space_id is not None:
            self.cloud_space_id = cloud_space_id
        if cluster_driver is not None:
            self.cluster_driver = cluster_driver
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if compute_config is not None:
            self.compute_config = compute_config
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if data_connections is not None:
            self.data_connections = data_connections
        if desired_state is not None:
            self.desired_state = desired_state
        if drives is not None:
            self.drives = drives
        if env is not None:
            self.env = env
        if lightningapp_instance_id is not None:
            self.lightningapp_instance_id = lightningapp_instance_id
        if network_config is not None:
            self.network_config = network_config
        if pause_automation is not None:
            self.pause_automation = pause_automation
        if restart_policy is not None:
            self.restart_policy = restart_policy
        if user_id is not None:
            self.user_id = user_id
        if user_requested_compute_config is not None:
            self.user_requested_compute_config = user_requested_compute_config

    @property
    def build_spec(self) -> 'V1BuildSpec':
        """Gets the build_spec of this V1LightningworkSpec.  # noqa: E501


        :return: The build_spec of this V1LightningworkSpec.  # noqa: E501
        :rtype: V1BuildSpec
        """
        return self._build_spec

    @build_spec.setter
    def build_spec(self, build_spec: 'V1BuildSpec'):
        """Sets the build_spec of this V1LightningworkSpec.


        :param build_spec: The build_spec of this V1LightningworkSpec.  # noqa: E501
        :type: V1BuildSpec
        """

        self._build_spec = build_spec

    @property
    def cloud_space_id(self) -> 'str':
        """Gets the cloud_space_id of this V1LightningworkSpec.  # noqa: E501


        :return: The cloud_space_id of this V1LightningworkSpec.  # noqa: E501
        :rtype: str
        """
        return self._cloud_space_id

    @cloud_space_id.setter
    def cloud_space_id(self, cloud_space_id: 'str'):
        """Sets the cloud_space_id of this V1LightningworkSpec.


        :param cloud_space_id: The cloud_space_id of this V1LightningworkSpec.  # noqa: E501
        :type: str
        """

        self._cloud_space_id = cloud_space_id

    @property
    def cluster_driver(self) -> 'V1LightningworkClusterDriver':
        """Gets the cluster_driver of this V1LightningworkSpec.  # noqa: E501


        :return: The cluster_driver of this V1LightningworkSpec.  # noqa: E501
        :rtype: V1LightningworkClusterDriver
        """
        return self._cluster_driver

    @cluster_driver.setter
    def cluster_driver(self, cluster_driver: 'V1LightningworkClusterDriver'):
        """Sets the cluster_driver of this V1LightningworkSpec.


        :param cluster_driver: The cluster_driver of this V1LightningworkSpec.  # noqa: E501
        :type: V1LightningworkClusterDriver
        """

        self._cluster_driver = cluster_driver

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1LightningworkSpec.  # noqa: E501


        :return: The cluster_id of this V1LightningworkSpec.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1LightningworkSpec.


        :param cluster_id: The cluster_id of this V1LightningworkSpec.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def compute_config(self) -> 'V1ComputeConfig':
        """Gets the compute_config of this V1LightningworkSpec.  # noqa: E501


        :return: The compute_config of this V1LightningworkSpec.  # noqa: E501
        :rtype: V1ComputeConfig
        """
        return self._compute_config

    @compute_config.setter
    def compute_config(self, compute_config: 'V1ComputeConfig'):
        """Sets the compute_config of this V1LightningworkSpec.


        :param compute_config: The compute_config of this V1LightningworkSpec.  # noqa: E501
        :type: V1ComputeConfig
        """

        self._compute_config = compute_config

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this V1LightningworkSpec.  # noqa: E501


        :return: The data_connection_mounts of this V1LightningworkSpec.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this V1LightningworkSpec.


        :param data_connection_mounts: The data_connection_mounts of this V1LightningworkSpec.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def data_connections(self) -> 'list[V1DataConnection]':
        """Gets the data_connections of this V1LightningworkSpec.  # noqa: E501


        :return: The data_connections of this V1LightningworkSpec.  # noqa: E501
        :rtype: list[V1DataConnection]
        """
        return self._data_connections

    @data_connections.setter
    def data_connections(self, data_connections: 'list[V1DataConnection]'):
        """Sets the data_connections of this V1LightningworkSpec.


        :param data_connections: The data_connections of this V1LightningworkSpec.  # noqa: E501
        :type: list[V1DataConnection]
        """

        self._data_connections = data_connections

    @property
    def desired_state(self) -> 'V1LightningworkState':
        """Gets the desired_state of this V1LightningworkSpec.  # noqa: E501


        :return: The desired_state of this V1LightningworkSpec.  # noqa: E501
        :rtype: V1LightningworkState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1LightningworkState'):
        """Sets the desired_state of this V1LightningworkSpec.


        :param desired_state: The desired_state of this V1LightningworkSpec.  # noqa: E501
        :type: V1LightningworkState
        """

        self._desired_state = desired_state

    @property
    def drives(self) -> 'list[V1LightningworkDrives]':
        """Gets the drives of this V1LightningworkSpec.  # noqa: E501


        :return: The drives of this V1LightningworkSpec.  # noqa: E501
        :rtype: list[V1LightningworkDrives]
        """
        return self._drives

    @drives.setter
    def drives(self, drives: 'list[V1LightningworkDrives]'):
        """Sets the drives of this V1LightningworkSpec.


        :param drives: The drives of this V1LightningworkSpec.  # noqa: E501
        :type: list[V1LightningworkDrives]
        """

        self._drives = drives

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this V1LightningworkSpec.  # noqa: E501


        :return: The env of this V1LightningworkSpec.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this V1LightningworkSpec.


        :param env: The env of this V1LightningworkSpec.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def lightningapp_instance_id(self) -> 'str':
        """Gets the lightningapp_instance_id of this V1LightningworkSpec.  # noqa: E501


        :return: The lightningapp_instance_id of this V1LightningworkSpec.  # noqa: E501
        :rtype: str
        """
        return self._lightningapp_instance_id

    @lightningapp_instance_id.setter
    def lightningapp_instance_id(self, lightningapp_instance_id: 'str'):
        """Sets the lightningapp_instance_id of this V1LightningworkSpec.


        :param lightningapp_instance_id: The lightningapp_instance_id of this V1LightningworkSpec.  # noqa: E501
        :type: str
        """

        self._lightningapp_instance_id = lightningapp_instance_id

    @property
    def network_config(self) -> 'list[V1NetworkConfig]':
        """Gets the network_config of this V1LightningworkSpec.  # noqa: E501


        :return: The network_config of this V1LightningworkSpec.  # noqa: E501
        :rtype: list[V1NetworkConfig]
        """
        return self._network_config

    @network_config.setter
    def network_config(self, network_config: 'list[V1NetworkConfig]'):
        """Sets the network_config of this V1LightningworkSpec.


        :param network_config: The network_config of this V1LightningworkSpec.  # noqa: E501
        :type: list[V1NetworkConfig]
        """

        self._network_config = network_config

    @property
    def pause_automation(self) -> 'bool':
        """Gets the pause_automation of this V1LightningworkSpec.  # noqa: E501


        :return: The pause_automation of this V1LightningworkSpec.  # noqa: E501
        :rtype: bool
        """
        return self._pause_automation

    @pause_automation.setter
    def pause_automation(self, pause_automation: 'bool'):
        """Sets the pause_automation of this V1LightningworkSpec.


        :param pause_automation: The pause_automation of this V1LightningworkSpec.  # noqa: E501
        :type: bool
        """

        self._pause_automation = pause_automation

    @property
    def restart_policy(self) -> 'V1LightningappRestartPolicy':
        """Gets the restart_policy of this V1LightningworkSpec.  # noqa: E501


        :return: The restart_policy of this V1LightningworkSpec.  # noqa: E501
        :rtype: V1LightningappRestartPolicy
        """
        return self._restart_policy

    @restart_policy.setter
    def restart_policy(self, restart_policy: 'V1LightningappRestartPolicy'):
        """Sets the restart_policy of this V1LightningworkSpec.


        :param restart_policy: The restart_policy of this V1LightningworkSpec.  # noqa: E501
        :type: V1LightningappRestartPolicy
        """

        self._restart_policy = restart_policy

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1LightningworkSpec.  # noqa: E501


        :return: The user_id of this V1LightningworkSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1LightningworkSpec.


        :param user_id: The user_id of this V1LightningworkSpec.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_requested_compute_config(self) -> 'V1UserRequestedComputeConfig':
        """Gets the user_requested_compute_config of this V1LightningworkSpec.  # noqa: E501


        :return: The user_requested_compute_config of this V1LightningworkSpec.  # noqa: E501
        :rtype: V1UserRequestedComputeConfig
        """
        return self._user_requested_compute_config

    @user_requested_compute_config.setter
    def user_requested_compute_config(self, user_requested_compute_config: 'V1UserRequestedComputeConfig'):
        """Sets the user_requested_compute_config of this V1LightningworkSpec.


        :param user_requested_compute_config: The user_requested_compute_config of this V1LightningworkSpec.  # noqa: E501
        :type: V1UserRequestedComputeConfig
        """

        self._user_requested_compute_config = user_requested_compute_config

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LightningworkSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningworkSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningworkSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1LightningworkSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ProjectClusterBinding(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'cluster_name': 'str',
        'cluster_region': 'str',
        'created_at': 'datetime',
        'is_cluster_healthy': 'bool',
        'project_id': 'str',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'cluster_id': 'clusterId',
        'cluster_name': 'clusterName',
        'cluster_region': 'clusterRegion',
        'created_at': 'createdAt',
        'is_cluster_healthy': 'isClusterHealthy',
        'project_id': 'projectId',
        'updated_at': 'updatedAt'
    }

    def __init__(self, cluster_id: 'str' =None, cluster_name: 'str' =None, cluster_region: 'str' =None, created_at: 'datetime' =None, is_cluster_healthy: 'bool' =None, project_id: 'str' =None, updated_at: 'datetime' =None):  # noqa: E501
        """V1ProjectClusterBinding - a model defined in Swagger"""  # noqa: E501
        self._cluster_id = None
        self._cluster_name = None
        self._cluster_region = None
        self._created_at = None
        self._is_cluster_healthy = None
        self._project_id = None
        self._updated_at = None
        self.discriminator = None
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if cluster_name is not None:
            self.cluster_name = cluster_name
        if cluster_region is not None:
            self.cluster_region = cluster_region
        if created_at is not None:
            self.created_at = created_at
        if is_cluster_healthy is not None:
            self.is_cluster_healthy = is_cluster_healthy
        if project_id is not None:
            self.project_id = project_id
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1ProjectClusterBinding.  # noqa: E501


        :return: The cluster_id of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1ProjectClusterBinding.


        :param cluster_id: The cluster_id of this V1ProjectClusterBinding.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def cluster_name(self) -> 'str':
        """Gets the cluster_name of this V1ProjectClusterBinding.  # noqa: E501


        :return: The cluster_name of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name: 'str'):
        """Sets the cluster_name of this V1ProjectClusterBinding.


        :param cluster_name: The cluster_name of this V1ProjectClusterBinding.  # noqa: E501
        :type: str
        """

        self._cluster_name = cluster_name

    @property
    def cluster_region(self) -> 'str':
        """Gets the cluster_region of this V1ProjectClusterBinding.  # noqa: E501


        :return: The cluster_region of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: str
        """
        return self._cluster_region

    @cluster_region.setter
    def cluster_region(self, cluster_region: 'str'):
        """Sets the cluster_region of this V1ProjectClusterBinding.


        :param cluster_region: The cluster_region of this V1ProjectClusterBinding.  # noqa: E501
        :type: str
        """

        self._cluster_region = cluster_region

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1ProjectClusterBinding.  # noqa: E501


        :return: The created_at of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1ProjectClusterBinding.


        :param created_at: The created_at of this V1ProjectClusterBinding.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def is_cluster_healthy(self) -> 'bool':
        """Gets the is_cluster_healthy of this V1ProjectClusterBinding.  # noqa: E501


        :return: The is_cluster_healthy of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: bool
        """
        return self._is_cluster_healthy

    @is_cluster_healthy.setter
    def is_cluster_healthy(self, is_cluster_healthy: 'bool'):
        """Sets the is_cluster_healthy of this V1ProjectClusterBinding.


        :param is_cluster_healthy: The is_cluster_healthy of this V1ProjectClusterBinding.  # noqa: E501
        :type: bool
        """

        self._is_cluster_healthy = is_cluster_healthy

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1ProjectClusterBinding.  # noqa: E501


        :return: The project_id of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1ProjectClusterBinding.


        :param project_id: The project_id of this V1ProjectClusterBinding.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1ProjectClusterBinding.  # noqa: E501


        :return: The updated_at of this V1ProjectClusterBinding.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1ProjectClusterBinding.


        :param updated_at: The updated_at of this V1ProjectClusterBinding.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ProjectClusterBinding, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ProjectClusterBinding') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ProjectClusterBinding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ProjectClusterBinding') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class ProjectsServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def projects_service_create_project(self, body: 'V1CreateProjectRequest', **kwargs) -> 'V1Project':  # noqa: E501
        """Project management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1CreateProjectRequest body: (required)
        :return: V1Project
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_create_project_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_create_project_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def projects_service_create_project_with_http_info(self, body: 'V1CreateProjectRequest', **kwargs) -> 'V1Project':  # noqa: E501
        """Project management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1CreateProjectRequest body: (required)
        :return: V1Project
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_create_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_create_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Project',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_create_project_cluster_binding(self, body: 'ProjectIdProjectclustersbindingsBody', project_id: 'str', **kwargs) -> 'V1ProjectClusterBinding':  # noqa: E501
        """projects_service_create_project_cluster_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_cluster_binding(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdProjectclustersbindingsBody body: (required)
        :param str project_id: (required)
        :return: V1ProjectClusterBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_create_project_cluster_binding_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_create_project_cluster_binding_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_create_project_cluster_binding_with_http_info(self, body: 'ProjectIdProjectclustersbindingsBody', project_id: 'str', **kwargs) -> 'V1ProjectClusterBinding':  # noqa: E501
        """projects_service_create_project_cluster_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_cluster_binding_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdProjectclustersbindingsBody body: (required)
        :param str project_id: (required)
        :return: V1ProjectClusterBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_create_project_cluster_binding" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_create_project_cluster_binding`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_create_project_cluster_binding`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/projectclustersbindings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectClusterBinding',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_create_project_membership(self, body: 'ProjectIdMembershipsBody', project_id: 'str', **kwargs) -> 'V1ProjectMembership':  # noqa: E501
        """projects_service_create_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_membership(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdMembershipsBody body: (required)
        :param str project_id: (required)
        :return: V1ProjectMembership
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_create_project_membership_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_create_project_membership_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_create_project_membership_with_http_info(self, body: 'ProjectIdMembershipsBody', project_id: 'str', **kwargs) -> 'V1ProjectMembership':  # noqa: E501
        """projects_service_create_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_membership_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdMembershipsBody body: (required)
        :param str project_id: (required)
        :return: V1ProjectMembership
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_create_project_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_create_project_membership`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_create_project_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/memberships', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectMembership',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_create_project_membership_role_binding(self, body: 'UserIdMembershiprolebindingsBody1', project_id: 'str', user_id: 'str', **kwargs) -> 'V1ProjectMembershipRoleBinding':  # noqa: E501
        """projects_service_create_project_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_membership_role_binding(body, project_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserIdMembershiprolebindingsBody1 body: (required)
        :param str project_id: (required)
        :param str user_id: (required)
        :return: V1ProjectMembershipRoleBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_create_project_membership_role_binding_with_http_info(body, project_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_create_project_membership_role_binding_with_http_info(body, project_id, user_id, **kwargs)  # noqa: E501
            return data

    def projects_service_create_project_membership_role_binding_with_http_info(self, body: 'UserIdMembershiprolebindingsBody1', project_id: 'str', user_id: 'str', **kwargs) -> 'V1ProjectMembershipRoleBinding':  # noqa: E501
        """projects_service_create_project_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_membership_role_binding_with_http_info(body, project_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserIdMembershiprolebindingsBody1 body: (required)
        :param str project_id: (required)
        :param str user_id: (required)
        :return: V1ProjectMembershipRoleBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_create_project_membership_role_binding" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_create_project_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_create_project_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `projects_service_create_project_membership_role_binding`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/memberships/{userId}/membershiprolebindings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectMembershipRoleBinding',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_create_project_role(self, body: 'ProjectsProjectIdBody', project_id: 'str', **kwargs) -> 'V1Role':  # noqa: E501
        """projects_service_create_project_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_role(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectsProjectIdBody body: (required)
        :param str project_id: (required)
        :return: V1Role
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_create_project_role_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_create_project_role_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_create_project_role_with_http_info(self, body: 'ProjectsProjectIdBody', project_id: 'str', **kwargs) -> 'V1Role':  # noqa: E501
        """projects_service_create_project_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_create_project_role_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectsProjectIdBody body: (required)
        :param str project_id: (required)
        :return: V1Role
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_create_project_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_create_project_role`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_create_project_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Role',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_delete_project(self, id: 'str', **kwargs) -> 'V1DeleteProjectResponse':  # noqa: E501
        """projects_service_delete_project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param bool skip_balance_check:
        :param str balance_destination_id:
        :param bool is_org:
        :return: V1DeleteProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_delete_project_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_delete_project_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def projects_service_delete_project_with_http_info(self, id: 'str', **kwargs) -> 'V1DeleteProjectResponse':  # noqa: E501
        """projects_service_delete_project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param bool skip_balance_check:
        :param str balance_destination_id:
        :param bool is_org:
        :return: V1DeleteProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'skip_balance_check', 'balance_destination_id', 'is_org']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_delete_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `projects_service_delete_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'skip_balance_check' in params:
            query_params.append(('skipBalanceCheck', params['skip_balance_check']))  # noqa: E501
        if 'balance_destination_id' in params:
            query_params.append(('balanceDestinationId', params['balance_destination_id']))  # noqa: E501
        if 'is_org' in params:
            query_params.append(('isOrg', params['is_org']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_delete_project_cluster_binding(self, project_id: 'str', cluster_id: 'str', **kwargs) -> 'V1DeleteProjectClusterBindingResponse':  # noqa: E501
        """projects_service_delete_project_cluster_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_cluster_binding(project_id, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str cluster_id: (required)
        :return: V1DeleteProjectClusterBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_delete_project_cluster_binding_with_http_info(project_id, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_delete_project_cluster_binding_with_http_info(project_id, cluster_id, **kwargs)  # noqa: E501
            return data

    def projects_service_delete_project_cluster_binding_with_http_info(self, project_id: 'str', cluster_id: 'str', **kwargs) -> 'V1DeleteProjectClusterBindingResponse':  # noqa: E501
        """projects_service_delete_project_cluster_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_cluster_binding_with_http_info(project_id, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str cluster_id: (required)
        :return: V1DeleteProjectClusterBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'cluster_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_delete_project_cluster_binding" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_delete_project_cluster_binding`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `projects_service_delete_project_cluster_binding`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'cluster_id' in params:
            path_params['clusterId'] = params['cluster_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/projectclustersbindings/{clusterId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteProjectClusterBindingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_delete_project_membership(self, project_id: 'str', user_id: 'str', **kwargs) -> 'V1DeleteProjectMembershipResponse':  # noqa: E501
        """projects_service_delete_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_membership(project_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str user_id: (required)
        :return: V1DeleteProjectMembershipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_delete_project_membership_with_http_info(project_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_delete_project_membership_with_http_info(project_id, user_id, **kwargs)  # noqa: E501
            return data

    def projects_service_delete_project_membership_with_http_info(self, project_id: 'str', user_id: 'str', **kwargs) -> 'V1DeleteProjectMembershipResponse':  # noqa: E501
        """projects_service_delete_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_membership_with_http_info(project_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str user_id: (required)
        :return: V1DeleteProjectMembershipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_delete_project_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_delete_project_membership`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `projects_service_delete_project_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/memberships/{userId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteProjectMembershipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_delete_project_membership_role_binding(self, project_id: 'str', user_id: 'str', role_id: 'str', **kwargs) -> 'V1DeleteProjectMembershipRoleBindingResponse':  # noqa: E501
        """projects_service_delete_project_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_membership_role_binding(project_id, user_id, role_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str user_id: (required)
        :param str role_id: (required)
        :return: V1DeleteProjectMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_delete_project_membership_role_binding_with_http_info(project_id, user_id, role_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_delete_project_membership_role_binding_with_http_info(project_id, user_id, role_id, **kwargs)  # noqa: E501
            return data

    def projects_service_delete_project_membership_role_binding_with_http_info(self, project_id: 'str', user_id: 'str', role_id: 'str', **kwargs) -> 'V1DeleteProjectMembershipRoleBindingResponse':  # noqa: E501
        """projects_service_delete_project_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_membership_role_binding_with_http_info(project_id, user_id, role_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str user_id: (required)
        :param str role_id: (required)
        :return: V1DeleteProjectMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'user_id', 'role_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_delete_project_membership_role_binding" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_delete_project_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `projects_service_delete_project_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'role_id' is set
        if ('role_id' not in params or
                params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `projects_service_delete_project_membership_role_binding`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/memberships/{userId}/membershiprolebindings/{roleId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteProjectMembershipRoleBindingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_delete_project_role(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteProjectRoleResponse':  # noqa: E501
        """projects_service_delete_project_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_role(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteProjectRoleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_delete_project_role_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_delete_project_role_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def projects_service_delete_project_role_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteProjectRoleResponse':  # noqa: E501
        """projects_service_delete_project_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_delete_project_role_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteProjectRoleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_delete_project_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_delete_project_role`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `projects_service_delete_project_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/roles/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteProjectRoleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_get_project(self, id: 'str', **kwargs) -> 'V1Project':  # noqa: E501
        """projects_service_get_project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_get_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1Project
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_get_project_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_get_project_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def projects_service_get_project_with_http_info(self, id: 'str', **kwargs) -> 'V1Project':  # noqa: E501
        """projects_service_get_project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_get_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1Project
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_get_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `projects_service_get_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Project',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_get_project_role(self, project_id: 'str', id: 'str', **kwargs) -> 'V1Role':  # noqa: E501
        """projects_service_get_project_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_get_project_role(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1Role
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_get_project_role_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_get_project_role_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def projects_service_get_project_role_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1Role':  # noqa: E501
        """projects_service_get_project_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_get_project_role_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1Role
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_get_project_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_get_project_role`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `projects_service_get_project_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/roles/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Role',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_invite_project_membership(self, body: 'ProjectIdInviteBody', project_id: 'str', **kwargs) -> 'V1InviteProjectMembershipResponse':  # noqa: E501
        """projects_service_invite_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_invite_project_membership(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdInviteBody body: (required)
        :param str project_id: project_id to invite to (required)
        :return: V1InviteProjectMembershipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_invite_project_membership_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_invite_project_membership_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_invite_project_membership_with_http_info(self, body: 'ProjectIdInviteBody', project_id: 'str', **kwargs) -> 'V1InviteProjectMembershipResponse':  # noqa: E501
        """projects_service_invite_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_invite_project_membership_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdInviteBody body: (required)
        :param str project_id: project_id to invite to (required)
        :return: V1InviteProjectMembershipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_invite_project_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_invite_project_membership`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_invite_project_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/invite', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1InviteProjectMembershipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_list_memberships(self, **kwargs) -> 'V1ListMembershipsResponse':  # noqa: E501
        """ListMemberships returns all projects for the current user. Used to discover to what projects the current user has access to.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_memberships(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id:
        :param bool filter_by_user_id:
        :return: V1ListMembershipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_list_memberships_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_list_memberships_with_http_info(**kwargs)  # noqa: E501
            return data

    def projects_service_list_memberships_with_http_info(self, **kwargs) -> 'V1ListMembershipsResponse':  # noqa: E501
        """ListMemberships returns all projects for the current user. Used to discover to what projects the current user has access to.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_memberships_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id:
        :param bool filter_by_user_id:
        :return: V1ListMembershipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'filter_by_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_list_memberships" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'organization_id' in params:
            query_params.append(('organizationId', params['organization_id']))  # noqa: E501
        if 'filter_by_user_id' in params:
            query_params.append(('filterByUserId', params['filter_by_user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/memberships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListMembershipsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_list_project_cluster_bindings(self, project_id: 'str', **kwargs) -> 'V1ListProjectClusterBindingsResponse':  # noqa: E501
        """ListClusters returns the clusters that have been added to the project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_cluster_bindings(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListProjectClusterBindingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_list_project_cluster_bindings_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_list_project_cluster_bindings_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_list_project_cluster_bindings_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListProjectClusterBindingsResponse':  # noqa: E501
        """ListClusters returns the clusters that have been added to the project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_cluster_bindings_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListProjectClusterBindingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_list_project_cluster_bindings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_list_project_cluster_bindings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/projectclustersbindings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListProjectClusterBindingsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_list_project_membership_role_bindings(self, project_id: 'str', user_id: 'str', **kwargs) -> 'V1ListProjectMembershipRoleBindingResponse':  # noqa: E501
        """Membership role binding control (adding/removing roles from existing project members)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_membership_role_bindings(project_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str user_id: (required)
        :return: V1ListProjectMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_list_project_membership_role_bindings_with_http_info(project_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_list_project_membership_role_bindings_with_http_info(project_id, user_id, **kwargs)  # noqa: E501
            return data

    def projects_service_list_project_membership_role_bindings_with_http_info(self, project_id: 'str', user_id: 'str', **kwargs) -> 'V1ListProjectMembershipRoleBindingResponse':  # noqa: E501
        """Membership role binding control (adding/removing roles from existing project members)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_membership_role_bindings_with_http_info(project_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str user_id: (required)
        :return: V1ListProjectMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_list_project_membership_role_bindings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_list_project_membership_role_bindings`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `projects_service_list_project_membership_role_bindings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/memberships/{userId}/membershiprolebindings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListProjectMembershipRoleBindingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_list_project_memberships(self, project_id: 'str', **kwargs) -> 'V1ListProjectMembershipsResponse':  # noqa: E501
        """Membership management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_memberships(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListProjectMembershipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_list_project_memberships_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_list_project_memberships_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_list_project_memberships_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListProjectMembershipsResponse':  # noqa: E501
        """Membership management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_memberships_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListProjectMembershipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_list_project_memberships" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_list_project_memberships`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/memberships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListProjectMembershipsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_list_project_roles(self, project_id: 'str', **kwargs) -> 'V1ListProjectRolesResponse':  # noqa: E501
        """Role management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_roles(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListProjectRolesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_list_project_roles_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_list_project_roles_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def projects_service_list_project_roles_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListProjectRolesResponse':  # noqa: E501
        """Role management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_list_project_roles_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListProjectRolesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_list_project_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `projects_service_list_project_roles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListProjectRolesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def projects_service_update_project(self, body: 'ProjectsIdBody', id: 'str', **kwargs) -> 'V1Project':  # noqa: E501
        """projects_service_update_project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_update_project(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectsIdBody body: (required)
        :param str id: (required)
        :return: V1Project
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.projects_service_update_project_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.projects_service_update_project_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def projects_service_update_project_with_http_info(self, body: 'ProjectsIdBody', id: 'str', **kwargs) -> 'V1Project':  # noqa: E501
        """projects_service_update_project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.projects_service_update_project_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectsIdBody body: (required)
        :param str id: (required)
        :return: V1Project
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method projects_service_update_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `projects_service_update_project`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `projects_service_update_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Project',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class ProjectIdDatasetsBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_space_id': 'str',
        'cluster_id': 'str',
        'compression': 'str',
        'creator_id': 'str',
        'data_format': 'str',
        'empty': 'bool',
        'input_dir': 'str',
        'lightning_app_id': 'str',
        'name': 'str',
        'num_bytes': 'str',
        'num_bytes_per_chunk': 'list[str]',
        'num_chunks': 'str',
        'size': 'str',
        'storage_dir': 'str',
        'type': 'V1DatasetType',
        'version': 'str'
    }

    attribute_map = {
        'cloud_space_id': 'cloudSpaceId',
        'cluster_id': 'clusterId',
        'compression': 'compression',
        'creator_id': 'creatorId',
        'data_format': 'dataFormat',
        'empty': 'empty',
        'input_dir': 'inputDir',
        'lightning_app_id': 'lightningAppId',
        'name': 'name',
        'num_bytes': 'numBytes',
        'num_bytes_per_chunk': 'numBytesPerChunk',
        'num_chunks': 'numChunks',
        'size': 'size',
        'storage_dir': 'storageDir',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, cloud_space_id: 'str' =None, cluster_id: 'str' =None, compression: 'str' =None, creator_id: 'str' =None, data_format: 'str' =None, empty: 'bool' =None, input_dir: 'str' =None, lightning_app_id: 'str' =None, name: 'str' =None, num_bytes: 'str' =None, num_bytes_per_chunk: 'list[str]' =None, num_chunks: 'str' =None, size: 'str' =None, storage_dir: 'str' =None, type: 'V1DatasetType' =None, version: 'str' =None):  # noqa: E501
        """ProjectIdDatasetsBody - a model defined in Swagger"""  # noqa: E501
        self._cloud_space_id = None
        self._cluster_id = None
        self._compression = None
        self._creator_id = None
        self._data_format = None
        self._empty = None
        self._input_dir = None
        self._lightning_app_id = None
        self._name = None
        self._num_bytes = None
        self._num_bytes_per_chunk = None
        self._num_chunks = None
        self._size = None
        self._storage_dir = None
        self._type = None
        self._version = None
        self.discriminator = None
        if cloud_space_id is not None:
            self.cloud_space_id = cloud_space_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if compression is not None:
            self.compression = compression
        if creator_id is not None:
            self.creator_id = creator_id
        if data_format is not None:
            self.data_format = data_format
        if empty is not None:
            self.empty = empty
        if input_dir is not None:
            self.input_dir = input_dir
        if lightning_app_id is not None:
            self.lightning_app_id = lightning_app_id
        if name is not None:
            self.name = name
        if num_bytes is not None:
            self.num_bytes = num_bytes
        if num_bytes_per_chunk is not None:
            self.num_bytes_per_chunk = num_bytes_per_chunk
        if num_chunks is not None:
            self.num_chunks = num_chunks
        if size is not None:
            self.size = size
        if storage_dir is not None:
            self.storage_dir = storage_dir
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def cloud_space_id(self) -> 'str':
        """Gets the cloud_space_id of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The cloud_space_id of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._cloud_space_id

    @cloud_space_id.setter
    def cloud_space_id(self, cloud_space_id: 'str'):
        """Sets the cloud_space_id of this ProjectIdDatasetsBody.


        :param cloud_space_id: The cloud_space_id of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._cloud_space_id = cloud_space_id

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The cluster_id of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this ProjectIdDatasetsBody.


        :param cluster_id: The cluster_id of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def compression(self) -> 'str':
        """Gets the compression of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The compression of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._compression

    @compression.setter
    def compression(self, compression: 'str'):
        """Sets the compression of this ProjectIdDatasetsBody.


        :param compression: The compression of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._compression = compression

    @property
    def creator_id(self) -> 'str':
        """Gets the creator_id of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The creator_id of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id: 'str'):
        """Sets the creator_id of this ProjectIdDatasetsBody.


        :param creator_id: The creator_id of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def data_format(self) -> 'str':
        """Gets the data_format of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The data_format of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._data_format

    @data_format.setter
    def data_format(self, data_format: 'str'):
        """Sets the data_format of this ProjectIdDatasetsBody.


        :param data_format: The data_format of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._data_format = data_format

    @property
    def empty(self) -> 'bool':
        """Gets the empty of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The empty of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty: 'bool'):
        """Sets the empty of this ProjectIdDatasetsBody.


        :param empty: The empty of this ProjectIdDatasetsBody.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    @property
    def input_dir(self) -> 'str':
        """Gets the input_dir of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The input_dir of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._input_dir

    @input_dir.setter
    def input_dir(self, input_dir: 'str'):
        """Sets the input_dir of this ProjectIdDatasetsBody.


        :param input_dir: The input_dir of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._input_dir = input_dir

    @property
    def lightning_app_id(self) -> 'str':
        """Gets the lightning_app_id of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The lightning_app_id of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._lightning_app_id

    @lightning_app_id.setter
    def lightning_app_id(self, lightning_app_id: 'str'):
        """Sets the lightning_app_id of this ProjectIdDatasetsBody.


        :param lightning_app_id: The lightning_app_id of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._lightning_app_id = lightning_app_id

    @property
    def name(self) -> 'str':
        """Gets the name of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The name of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this ProjectIdDatasetsBody.


        :param name: The name of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def num_bytes(self) -> 'str':
        """Gets the num_bytes of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The num_bytes of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._num_bytes

    @num_bytes.setter
    def num_bytes(self, num_bytes: 'str'):
        """Sets the num_bytes of this ProjectIdDatasetsBody.


        :param num_bytes: The num_bytes of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._num_bytes = num_bytes

    @property
    def num_bytes_per_chunk(self) -> 'list[str]':
        """Gets the num_bytes_per_chunk of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The num_bytes_per_chunk of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._num_bytes_per_chunk

    @num_bytes_per_chunk.setter
    def num_bytes_per_chunk(self, num_bytes_per_chunk: 'list[str]'):
        """Sets the num_bytes_per_chunk of this ProjectIdDatasetsBody.


        :param num_bytes_per_chunk: The num_bytes_per_chunk of this ProjectIdDatasetsBody.  # noqa: E501
        :type: list[str]
        """

        self._num_bytes_per_chunk = num_bytes_per_chunk

    @property
    def num_chunks(self) -> 'str':
        """Gets the num_chunks of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The num_chunks of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._num_chunks

    @num_chunks.setter
    def num_chunks(self, num_chunks: 'str'):
        """Sets the num_chunks of this ProjectIdDatasetsBody.


        :param num_chunks: The num_chunks of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._num_chunks = num_chunks

    @property
    def size(self) -> 'str':
        """Gets the size of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The size of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size: 'str'):
        """Sets the size of this ProjectIdDatasetsBody.


        :param size: The size of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def storage_dir(self) -> 'str':
        """Gets the storage_dir of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The storage_dir of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._storage_dir

    @storage_dir.setter
    def storage_dir(self, storage_dir: 'str'):
        """Sets the storage_dir of this ProjectIdDatasetsBody.


        :param storage_dir: The storage_dir of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._storage_dir = storage_dir

    @property
    def type(self) -> 'V1DatasetType':
        """Gets the type of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The type of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: V1DatasetType
        """
        return self._type

    @type.setter
    def type(self, type: 'V1DatasetType'):
        """Sets the type of this ProjectIdDatasetsBody.


        :param type: The type of this ProjectIdDatasetsBody.  # noqa: E501
        :type: V1DatasetType
        """

        self._type = type

    @property
    def version(self) -> 'str':
        """Gets the version of this ProjectIdDatasetsBody.  # noqa: E501


        :return: The version of this ProjectIdDatasetsBody.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this ProjectIdDatasetsBody.


        :param version: The version of this ProjectIdDatasetsBody.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectIdDatasetsBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'ProjectIdDatasetsBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectIdDatasetsBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'ProjectIdDatasetsBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1CloudSpaceInstanceCollabStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'edit_request_queue_user_ids': 'list[str]',
        'editor_user_id': 'str',
        'is_live': 'bool',
        'viewer_user_ids': 'list[str]'
    }

    attribute_map = {
        'edit_request_queue_user_ids': 'editRequestQueueUserIds',
        'editor_user_id': 'editorUserId',
        'is_live': 'isLive',
        'viewer_user_ids': 'viewerUserIds'
    }

    def __init__(self, edit_request_queue_user_ids: 'list[str]' =None, editor_user_id: 'str' =None, is_live: 'bool' =None, viewer_user_ids: 'list[str]' =None):  # noqa: E501
        """V1CloudSpaceInstanceCollabStatus - a model defined in Swagger"""  # noqa: E501
        self._edit_request_queue_user_ids = None
        self._editor_user_id = None
        self._is_live = None
        self._viewer_user_ids = None
        self.discriminator = None
        if edit_request_queue_user_ids is not None:
            self.edit_request_queue_user_ids = edit_request_queue_user_ids
        if editor_user_id is not None:
            self.editor_user_id = editor_user_id
        if is_live is not None:
            self.is_live = is_live
        if viewer_user_ids is not None:
            self.viewer_user_ids = viewer_user_ids

    @property
    def edit_request_queue_user_ids(self) -> 'list[str]':
        """Gets the edit_request_queue_user_ids of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501


        :return: The edit_request_queue_user_ids of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._edit_request_queue_user_ids

    @edit_request_queue_user_ids.setter
    def edit_request_queue_user_ids(self, edit_request_queue_user_ids: 'list[str]'):
        """Sets the edit_request_queue_user_ids of this V1CloudSpaceInstanceCollabStatus.


        :param edit_request_queue_user_ids: The edit_request_queue_user_ids of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :type: list[str]
        """

        self._edit_request_queue_user_ids = edit_request_queue_user_ids

    @property
    def editor_user_id(self) -> 'str':
        """Gets the editor_user_id of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501


        :return: The editor_user_id of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :rtype: str
        """
        return self._editor_user_id

    @editor_user_id.setter
    def editor_user_id(self, editor_user_id: 'str'):
        """Sets the editor_user_id of this V1CloudSpaceInstanceCollabStatus.


        :param editor_user_id: The editor_user_id of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :type: str
        """

        self._editor_user_id = editor_user_id

    @property
    def is_live(self) -> 'bool':
        """Gets the is_live of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501


        :return: The is_live of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :rtype: bool
        """
        return self._is_live

    @is_live.setter
    def is_live(self, is_live: 'bool'):
        """Sets the is_live of this V1CloudSpaceInstanceCollabStatus.


        :param is_live: The is_live of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :type: bool
        """

        self._is_live = is_live

    @property
    def viewer_user_ids(self) -> 'list[str]':
        """Gets the viewer_user_ids of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501


        :return: The viewer_user_ids of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._viewer_user_ids

    @viewer_user_ids.setter
    def viewer_user_ids(self, viewer_user_ids: 'list[str]'):
        """Sets the viewer_user_ids of this V1CloudSpaceInstanceCollabStatus.


        :param viewer_user_ids: The viewer_user_ids of this V1CloudSpaceInstanceCollabStatus.  # noqa: E501
        :type: list[str]
        """

        self._viewer_user_ids = viewer_user_ids

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1CloudSpaceInstanceCollabStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1CloudSpaceInstanceCollabStatus') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CloudSpaceInstanceCollabStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1CloudSpaceInstanceCollabStatus') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
